Skip to contents

Currently patchwork is used in the documentation but not in the package itself. This function is a workaround to avoid warnings about unused imports when building the package.

Usage

ignore_unused_imports()