This function takes a single character name/code and returns the
corresponding hex colour. It checks if the input is a valid hex colour code
or a valid R color name, and if not, it uses a predefined mapping for
specific color names like "rl_green", "rl_red", etc. If the input is not
valid, it will return NULL. Use of get_fp_color is valid too.