This function takes an integer n and a character scheme and returns a
character vector of n colours from the specified colour scheme. The
function supports four colour schemes from Paul Tol ("tol_bright",
"tol_vibrant", "tol_muted", "tol_light") and Color Universal Design ("cud"
scheme). If the scheme argument is a vector of colours, the function will
return the first n colours from that vector, repeating the vector if it has
fewer than n colours. If the scheme argument is not a valid colour scheme
or a vector of colours, the function will throw an error. Use of
get_sp_colors() is valid too.